@@ -101,9 +101,12 @@ newtype QuickCheckMaxShrinks = QuickCheckMaxShrinks Int
 
 instance IsOption QuickCheckTests where
   defaultValue = 100
-  parseValue = fmap QuickCheckTests . safeRead
+  parseValue =
+    -- We allow numeric underscores for readability; see
+    -- https://github.com/feuerbach/tasty/issues/263
+    fmap QuickCheckTests . safeRead . filter (/= '_')
   optionName = return "quickcheck-tests"
-  optionHelp = return "Number of test cases for QuickCheck to generate"
+  optionHelp = return "Number of test cases for QuickCheck to generate. Underscores accepted: e.g. 10_000_000"
   optionCLParser = mkOptionCLParser $ metavar "NUMBER"
 
 instance IsOption QuickCheckReplay where
